@@ -27,8 +27,8 @@ hotel2T2 <- function(x1, x2, a = 0.05, R = 999, graph = FALSE) {
   } else  colnames(mesoi) <- colnames(x1)
   v <- ( (n1 - 1) * Rfast::cova(x1) + (n2 - 1) * Rfast::cova(x2) )/(n - 2)
   ## v is the pooled covariance matrix
-  t2 <- ( n1 * n2 * (dbar %*% solve(v, dbar) ) )/n
-  test <- as.vector( (n - p - 1) * t2 / ( (n - 2) * p ) )  ## test statistic
+  t2 <- as.numeric( dbar %*% solve(v, dbar) )
+  test <- as.vector( n1 * n2 / n * (n - p - 1) * t2 / ( (n - 2) * p ) )  ## test statistic
 
   if ( R <= 1 ) {
     crit <- qf(1 - a, p, n - p - 1)  ## critical value of the F distribution
@@ -43,22 +43,33 @@ hotel2T2 <- function(x1, x2, a = 0.05, R = 999, graph = FALSE) {
     mc <- Rfast::colmeans( rbind(x1, x2) )  ## the combined sample mean vector
     ## the next two rows bring the mean vectors of the two sample equal
     ## to the combined mean and thus equal under the null hypothesis
-    mc1 <-  - xbar1 + mc
-    mc2 <-  - xbar2 + mc
+    mc1 <- mc - xbar1
+    mc2 <- mc - xbar2
     y1 <- Rfast::eachrow(x1, mc1, oper = "+")
     y2 <- Rfast::eachrow(x2, mc2, oper = "+" )
-    tb <- numeric(R)
-    for (i in 1:R) {
+    B <- round( sqrt(R) )
+    bm1 <- bm2 <- matrix(nrow = B, ncol = p)
+    vb1 <- vector("list", B)
+    vb2 <- vector("list", B)
+    tb <- matrix(0, B, B)
+    for (i in 1:B) {
       b1 <- sample(1:n1, n1, replace = TRUE)
       b2 <- sample(1:n2, n2, replace = TRUE)
       yb1 <- y1[b1, ]    ;   yb2 <- y2[b2, ]
-      db <- Rfast::colmeans(yb1) - Rfast::colmeans(yb2)  ## difference of the mean vectors
-      vb <- ( (n1 - 1) * Rfast::cova(yb1) + (n2 - 1) * Rfast::cova(y2) ) / (n - 2)
+      bm1[i, ] <- Rfast::colmeans(yb1)
+      bm2[i, ] <- Rfast::colmeans(yb2)  ## difference of the mean vectors
+      vb1[[ i ]] <- crossprod(yb1) - tcrossprod( sqrt(n1) * bm1[i, ])
+      vb2[[ i ]] <- crossprod(yb2) - tcrossprod( sqrt(n2) * bm2[i, ])
       ## vb is the pooled covariance matrix
-      tb[i] <- ( n1 * n2 * (db %*% solve(vb, db) ) ) / n
     }
-    tb <- ( (n - p - 1) * tb ) / ( (n - 2) * p )
-    pvalue <- ( sum(tb > test) + 1 )/(R + 1)
+    for (i in 1:B) {
+      for (j in 1:B) {
+        vb <- vb1[[ i ]] + vb2[[ j ]]
+        db <- bm1[i, ] - bm2[j, ]
+        tb[i, j] <- db %*% solve(vb, db)
+      }
+    }
+    pvalue <- ( sum(tb > t2) + 1 )/(B^2 + 1)
 
     if ( graph ) {
       hist(tb, xlab = "Bootstrapped test statistic", main = " ")
